@@ -273,6 +273,10 @@ caja_module_initialize (GTypeModule *module)
 {
     g_print ("Initializing caja-gksu extension\n");
     gksu_context_menu_register_type (module);
+#ifdef ENABLE_NLS
+    bindtextdomain (GETTEXT_PACKAGE, MATELOCALEDIR);
+    bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+#endif /* ENABLE_NLS */
 }
 
 void
