@@ -38,6 +38,10 @@ caja_module_initialize (GTypeModule *module)
 
 	caja_image_converter_register_type (module);
 	type_list[0] = CAJA_TYPE_IMAGE_CONVERTER;
+#ifdef ENABLE_NLS
+	bindtextdomain (GETTEXT_PACKAGE, MATELOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+#endif /* ENABLE_NLS */
 }
 
 void
