@@ -21,9 +21,13 @@
  * Author:  Roberto Majadas <roberto.majadas@openshine.com>
  */
 
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <string.h>
 #include <stdlib.h>
+#include <glib.h>
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
 #include <gtk/gtk.h>
@@ -34,10 +38,8 @@
 #define CAJA_SENDTO_STATUS_LABEL_TIMEOUT_SECONDS 10
 
 #define UNINSTALLED_PLUGINDIR "plugins/removable-devices"
-#define UNINSTALLED_SOURCE "caja-sendto-command.c"
 
 #define SOEXT           ("." G_MODULE_SUFFIX)
-#define SOEXT_LEN       (strlen (SOEXT))
 
 enum {
 	COLUMN_ICON,
@@ -315,8 +317,7 @@ send_button_cb (GtkWidget *widget, NS_ui *ui)
 		g_free (f);
 	} else {
 		if (!p->info->send_files (p, w, file_list)) {
-			g_list_foreach (file_list, (GFunc) g_free, NULL);
-			g_list_free (file_list);
+			g_list_free_full (file_list, g_free);
 			file_list = NULL;
 			return;
 		}
@@ -444,9 +445,13 @@ set_model_for_options_combobox (NS_ui *ui)
 						   GTK_ICON_LOOKUP_USE_BUILTIN, NULL);
 		gtk_list_store_append (model, &iter);
 		gtk_list_store_set (model, &iter,
-					COLUMN_ICON, pixbuf,
-					COLUMN_DESCRIPTION, dgettext(p->info->gettext_package, p->info->description),
-					-1);
+		                    COLUMN_ICON, pixbuf,
+#ifdef ENABLE_NLS
+		                    COLUMN_DESCRIPTION, g_dgettext (p->info->gettext_package, p->info->description),
+#else
+		                    COLUMN_DESCRIPTION, p->info->description,
+#endif /* ENABLE_NLS */
+		                    -1);
 		if (last_used != NULL && !strcmp(last_used, p->info->id)) {
 			option = i;
 			last_used_support_dirs = (p->info->capabilities & CAJA_CAPS_SEND_DIRECTORIES);
@@ -506,13 +511,13 @@ pack_entry_changed_cb (GObject *object, GParamSpec *spec, NS_ui *ui)
 }
 
 static void
-update_button_image (GtkSettings *settings,
-		     GParamSpec *spec,
-		     GtkWidget *widget)
+update_button_image (GtkSettings *gtk_settings,
+                     GParamSpec  *spec,
+                     GtkWidget   *widget)
 {
 	gboolean show_images;
 
-	g_object_get (settings, "gtk-button-images", &show_images, NULL);
+	g_object_get (gtk_settings, "gtk-button-images", &show_images, NULL);
 	if (show_images == FALSE)
 		gtk_widget_hide (widget);
 	else
@@ -522,7 +527,7 @@ update_button_image (GtkSettings *settings,
 static void
 caja_sendto_create_ui (void)
 {
-	GtkBuilder *app;
+	GtkBuilder *builder;
 	GError* error = NULL;
 	NS_ui *ui;
 	gboolean one_file = FALSE;
@@ -530,29 +535,29 @@ caja_sendto_create_ui (void)
 	GtkSettings *gtk_settings;
 	GtkWidget *button_image;
 
-	app = gtk_builder_new ();
-	if (gtk_builder_add_from_resource (app, "/org/mate/caja/extensions/sendto/caja-sendto.ui", &error) == 0) {
+	builder = gtk_builder_new ();
+	if (gtk_builder_add_from_resource (builder, "/org/mate/caja/extensions/sendto/caja-sendto.ui", &error) == 0) {
 		g_warning ("Could not parse UI definition: %s", error->message);
 		g_error_free (error);
 	}
 
 	ui = g_new0 (NS_ui, 1);
 
-	ui->hbox_contacts_ws = GTK_WIDGET (gtk_builder_get_object (app, "hbox_contacts_widgets"));
-	ui->send_to_label = GTK_WIDGET (gtk_builder_get_object (app, "send_to_label"));
-	ui->options_combobox = GTK_WIDGET (gtk_builder_get_object (app, "options_combobox"));
-	ui->dialog = GTK_WIDGET (gtk_builder_get_object (app, "caja_sendto_dialog"));
-	ui->cancel_button = GTK_WIDGET (gtk_builder_get_object (app, "cancel_button"));
-	ui->send_button = GTK_WIDGET (gtk_builder_get_object (app, "send_button"));
-	ui->pack_combobox = GTK_WIDGET (gtk_builder_get_object (app, "pack_combobox"));
-	ui->pack_entry = GTK_WIDGET (gtk_builder_get_object (app, "pack_entry"));
-	ui->pack_checkbutton = GTK_WIDGET (gtk_builder_get_object (app, "pack_checkbutton"));
-	ui->status_box = GTK_WIDGET (gtk_builder_get_object (app, "status_box"));
-	ui->status_label = GTK_WIDGET (gtk_builder_get_object (app, "status_label"));
-	ui->status_image = GTK_WIDGET (gtk_builder_get_object (app, "status_image"));
+	ui->hbox_contacts_ws = GTK_WIDGET (gtk_builder_get_object (builder, "hbox_contacts_widgets"));
+	ui->send_to_label = GTK_WIDGET (gtk_builder_get_object (builder, "send_to_label"));
+	ui->options_combobox = GTK_WIDGET (gtk_builder_get_object (builder, "options_combobox"));
+	ui->dialog = GTK_WIDGET (gtk_builder_get_object (builder, "caja_sendto_dialog"));
+	ui->cancel_button = GTK_WIDGET (gtk_builder_get_object (builder, "cancel_button"));
+	ui->send_button = GTK_WIDGET (gtk_builder_get_object (builder, "send_button"));
+	ui->pack_combobox = GTK_WIDGET (gtk_builder_get_object (builder, "pack_combobox"));
+	ui->pack_entry = GTK_WIDGET (gtk_builder_get_object (builder, "pack_entry"));
+	ui->pack_checkbutton = GTK_WIDGET (gtk_builder_get_object (builder, "pack_checkbutton"));
+	ui->status_box = GTK_WIDGET (gtk_builder_get_object (builder, "status_box"));
+	ui->status_label = GTK_WIDGET (gtk_builder_get_object (builder, "status_label"));
+	ui->status_image = GTK_WIDGET (gtk_builder_get_object (builder, "status_image"));
 
 	gtk_settings = gtk_settings_get_default ();
-	button_image = GTK_WIDGET (gtk_builder_get_object (app, "image1"));
+	button_image = GTK_WIDGET (gtk_builder_get_object (builder, "image1"));
 	g_signal_connect (G_OBJECT (gtk_settings), "notify::gtk-button-images",
 			  G_CALLBACK (update_button_image), button_image);
 	update_button_image (gtk_settings, NULL, button_image);
@@ -605,6 +610,8 @@ caja_sendto_create_ui (void)
 	g_signal_connect (G_OBJECT (ui->pack_checkbutton), "toggled",
 			  G_CALLBACK (toggle_pack_check), ui);
 
+	g_object_unref (builder);
+
 	if (has_dirs == FALSE || supports_dirs != FALSE) {
 		gboolean toggle;
 
@@ -638,21 +645,27 @@ caja_sendto_plugin_dir_process (const char *plugindir)
 	} else {
 		while ((item = g_dir_read_name(dir))) {
 			if (g_str_has_suffix (item, SOEXT)) {
-				char *module_path;
+				g_autofree gchar *module_path = NULL;
 
 				p = g_new0(NstPlugin, 1);
+
 				module_path = g_module_build_path (plugindir, item);
+				if (!module_path) {
+					g_free (p);
+					continue;
+				}
+
 				p->module = g_module_open (module_path, 0);
 			        if (!p->module) {
                 			g_warning ("error opening %s: %s", module_path, g_module_error ());
-					g_free (module_path);
+					g_free (p);
 					continue;
 				}
-				g_free (module_path);
 
 				if (!g_module_symbol (p->module, "nst_init_plugin", (gpointer *) &nst_init_plugin)) {
 			                g_warning ("error: %s", g_module_error ());
 					g_module_close (p->module);
+					g_free (p);
 					continue;
 				}
 
@@ -790,9 +803,11 @@ int main (int argc, char **argv)
 	GOptionContext *context;
 	GError *error = NULL;
 
-	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+#ifdef ENABLE_NLS
+	bindtextdomain (GETTEXT_PACKAGE, MATELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
+#endif /* ENABLE_NLS */
 
 	context = g_option_context_new ("");
 	g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
