@@ -1263,6 +1263,10 @@ caja_module_initialize (GTypeModule  *module)
   g_print ("Initializing caja-share extension\n");
 
   caja_share_register_type (module);
+#ifdef ENABLE_NLS
+  bindtextdomain (GETTEXT_PACKAGE, MATELOCALEDIR);
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+#endif /* ENABLE_NLS */
 }
 
 /* Perform module-specific shutdown. */
